@@ -287,6 +287,32 @@ def test_umat():
     dsde = linear_elastic.hessian([F, None])
 
 
+def test_umat_hyperelastic():
+    r, x = pre(sym=False, add_identity=True)
+    F = x[0]
+
+    import tensortrax.math as tm
+
+    def neo_hooke(C, mu=1):
+        return mu / 2 * (tm.linalg.det(C) ** (-1 / 3) * tm.trace(C) - 3)
+
+    for model, kwargs in [
+        (neo_hooke, {"mu": 1}),
+        (fe.constitution.neo_hooke, {"mu": 1}),
+        (fe.constitution.yeoh, {"C10": 0.5, "C20": -0.1, "C30": 0.02}),
+        (
+            fe.constitution.third_order_deformation,
+            {"C10": 0.5, "C01": 0.1, "C11": 0.01, "C20": -0.1, "C30": 0.02},
+        ),
+        (fe.constitution.ogden, {"mu": [1], "alpha": [1.7]}),
+    ]:
+
+        umat = fe.UserMaterialHyperelastic(model, **kwargs)
+
+        s, statevars_new = umat.gradient([F, None])
+        dsde = umat.hessian([F, None])
+
+
 def test_umat_strain():
 
     r, x = pre(sym=False, add_identity=True)
@@ -342,6 +368,7 @@ if __name__ == "__main__":
     test_linear_planestrain()
     test_kinematics()
     test_umat()
+    test_umat_hyperelastic()
     test_umat_strain()
     test_umat_strain_plasticity()
     test_elpliso()
